@@ -72,15 +72,17 @@ class JsLintComplaint(object):
 
 class JSLintAnalyzer(Analyzer):
 
-    def __init__(self, lib_path=None, use_nodejs_if_available=True):
+    def __init__(self, options=None):
+        self._options = options or {}
         self._js_lint_proc_args = None
         self._module_path = os.path.dirname(os.path.realpath(__file__))
-        self._lib_path = lib_path or os.path.join(self._module_path, 'lib')
+        self._lib_path = self._options.get('lib_path', os.path.join(self._module_path, 'lib'))
         self._jslint_script_regex = re.compile(r'^jslint.*\.js$')
         self._js_lint_script_file_path = first_file_name_in_path_matching_regex(self._lib_path, self._jslint_script_regex)
         self._rhino_jar_regex = re.compile(r'^js\.jar$')
         self._rhino_jar_file_path = first_file_name_in_path_matching_regex(self._lib_path, self._rhino_jar_regex)
         self._lib_message_list = []
+        self._use_nodejs_if_available = self._options.get('use_nodejs_if_available', True)
 
         if self._js_lint_proc_args is None and platform.system() == 'Windows':
             # Windows Script Host has two versions, wscript.exe which pops up
@@ -88,7 +90,7 @@ class JSLintAnalyzer(Analyzer):
             self._js_lint_proc_args = ["cscript.exe", "//I", "//Nologo", self._js_lint_script_file_path]
             self._lib_message_list.append("Using cscript.exe to run JSLint")
 
-        if self._js_lint_proc_args is None and use_nodejs_if_available:
+        if self._js_lint_proc_args is None and self._use_nodejs_if_available:
             null_file = open(os.devnull, 'w')
             try:
                 subprocess.check_call(['node', '--help'], stdout=null_file, stderr=null_file)
@@ -120,7 +122,7 @@ class JSLintAnalyzer(Analyzer):
             js_lint_proc_outputs = js_lint_proc.communicate(resource.content)
         except Exception as e:
             analysis.add_error("An exception what thrown while running JsLint: %s\n%s" %
-                (str(e), traceback.format_exc))
+                (str(e), traceback.format_exc()))
             return analysis
 
         # The JSLint process returns 1 if it finds lint
