@@ -139,10 +139,14 @@ class Resource:
                 else:
                     name = str(result.group('require_match'))
 
-            insert_position = (result.start(), result.end())
-            if self._requirements is None:
-                self._requirements = []
-            self._requirements.append(Requirement(name, insert_position))
+            # blend does not try to bring in a file referenced by a url that
+            # starts with /, //, http://, etc. (remote CSS imports)
+            absolute_path_regex = re.compile(r'^([a-zA-Z]+\:){0,1}[\/]{1,2}')
+            if not absolute_path_regex.search(name):
+                insert_position = (result.start(), result.end())
+                if self._requirements is None:
+                    self._requirements = []
+                self._requirements.append(Requirement(name, insert_position))
 
     @staticmethod
     def _parse_extension_and_file_type(path_to_file):
