@@ -390,3 +390,16 @@ class TestResource(unittest.TestCase):
         self.assertFalse(unminified_resource.minified)
         self.assertTrue(minified_resource_with_dot.minified)
         self.assertTrue(minified_resource_with_dash.minified)
+
+    def test_remote_css_requires_are_not_included(self):
+        test_file_paths = [
+            os.path.join(self.test_env_dir, 'main.css')
+        ]
+        helpers.clean_up_files(test_file_paths)
+        helpers.create_file_with_content(test_file_paths[0],
+            '@import url("lib.css")\n@import url("//fonts.google")\n')
+
+        resource = Resource(test_file_paths[0])
+        self.assertEqual(1, len(resource.requirements))
+
+        helpers.clean_up_files(test_file_paths)
